@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 <Program Name>
   aggregate_tests.py
@@ -26,9 +24,10 @@
 import sys
 import unittest
 
-if __name__ == '__main__':
-  suite = unittest.TestLoader().discover("tests", top_level_dir=".")
-  all_tests_passed = unittest.TextTestRunner(
-      verbosity=1, buffer=True).run(suite).wasSuccessful()
-  if not all_tests_passed:
-    sys.exit(1)
+if __name__ == "__main__":
+    suite = unittest.TestLoader().discover("tests", top_level_dir=".")
+    all_tests_passed = (
+        unittest.TextTestRunner(verbosity=2, buffer=True).run(suite).wasSuccessful()
+    )
+    if not all_tests_passed:
+        sys.exit(1)
